@@ -40,49 +40,59 @@ class Processor(Consumer):
 
         self.client = QdrantClient(url=store_uri)
 
+    def get_collection(self, dim, user, collection):
+
+        cname = (
+            "t_" + user + "_" + collection + "_" + str(dim)
+        )
+
+        if cname != self.last_collection:
+
+            if not self.client.collection_exists(cname):
+
+                try:
+                    self.client.create_collection(
+                        collection_name=cname,
+                        vectors_config=VectorParams(
+                            size=dim, distance=Distance.COSINE
+                        ),
+                    )
+                except Exception as e:
+                    print("Qdrant collection creation failed")
+                    raise e
+
+            self.last_collection = cname
+
+        return cname
+
     def handle(self, msg):
 
         v = msg.value()
 
-        if v.entity.value == "" or v.entity.value is None: return
+        for entity in v.entities:
 
-        for vec in v.vectors:
+            if entity.entity.value == "" or entity.entity.value is None: return
 
-            dim = len(vec)
-            collection = (
-                "t_" + v.metadata.user + "_" + v.metadata.collection + "_" +
-                str(dim)
-            )
+            for vec in entity.vectors:
 
-            if collection != self.last_collection:
+                dim = len(vec)
 
-                if not self.client.collection_exists(collection):
+                collection = self.get_collection(
+                    dim, v.metadata.user, v.metadata.collection
+                )
 
-                    try:
-                        self.client.create_collection(
-                            collection_name=collection,
-                            vectors_config=VectorParams(
-                                size=dim, distance=Distance.DOT
-                            ),
+                self.client.upsert(
+                    collection_name=collection,
+                    points=[
+                        PointStruct(
+                            id=str(uuid.uuid4()),
+                            vector=vec,
+                            payload={
+                                "entity": entity.entity.value,
+                            }
                         )
-                    except Exception as e:
-                        print("Qdrant collection creation failed")
-                        raise e
-
-                self.last_collection = collection
-
-            self.client.upsert(
-                collection_name=collection,
-                points=[
-                    PointStruct(
-                        id=str(uuid.uuid4()),
-                        vector=vec,
-                        payload={
-                            "entity": v.entity.value,
-                        }
-                    )
-                ]
-            )
+                    ]
+                )
 
     @staticmethod
     def add_args(parser):
